==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/coin/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Controle de moedas(Coin)',
    'version': '7.0.21.12.14',
    'category': 'others',
    'description': """
    Modulo para controle de criptomoedas
    """,
    'author': 'Sig Informatica Ltda',
    'website': 'http: //www.siginformatica.com.br',
    'depends': [
        'adm'
    ],
    'data': [
        'views/brokers_view.xml',
        'views/moedas_view.xml',
        'views/ticker_view.xml',
        'views/trades_view.xml',
        'views/robot_view.xml',
        'views/orders_view.xml',

        'wizard/variacao_view.xml',

        'data/moedas.xml',
        'data/brokers.xml',
        'data/ir_cron.xml',

        'security/security.xml',
        'security/ir.model.access.csv',

        'views/actions.xml',
        'views/menu.xml',
    ],
    'installable': True,
    "application": True,
    'active': False,
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/coin/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Controle de moedas(Coin)',
    'version': '7.0.2310.2',
    'category': 'others',
    'description': """
    Modulo para controle de criptomoedas
    """,
    'author': 'Sig Informatica Ltda',
    'website': 'http: //www.siginformatica.com.br',
    'depends': [
        'adm'
    ],
    'data': [
        'views/brokers_view.xml',
        'views/moedas_view.xml',
        'views/ticker_view.xml',
        'views/trades_view.xml',
        'views/robot_view.xml',
        'views/orders_view.xml',

        'wizard/variacao_view.xml',

        'data/moedas.xml',
        'data/brokers.xml',
        'data/ir_cron.xml',

        'security/security.xml',
        'security/ir.model.access.csv',

        'views/actions.xml',
        'views/menu.xml',
    ],
    'installable': True,
    "application": True,
    'active': False,
}
